<?php

namespace AuthStack\AuthProfile\Facade;

use Illuminate\Support\Facades\Facade;

class ProfileManager extends Facade
{
    protected static function getFacadeAccessor()
    {
        return 'ProfileManager';
    }
}