<?php

/*
 * This file is part of the AuthStack project.
 *
 * (c) Buckhill Ltd <development@buckhill.co.uk>
 *
 * This source file is subject to the Buckhill license that is bundled
 * with this source code in the file LICENSE.
 *
 */

use \mageekguy\atoum;

// HTML

/*
Please replace in next line /path/to/destination/directory by your destination directory path for html files.
*/
$coverageHtmlField = new atoum\report\fields\runner\coverage\html('Authentication profiles for AuthStack', '/var/www/coverage/authstack/authprofile/coverage');

/*
Please replace in next line http://url/of/web/site by the root url of your code coverage web site.
*/
$coverageHtmlField->setRootUrl('http://coverage.buckhill.com.hr/authstack/authprofile/coverage');

// Treemap (not mandatory)

/*
Please replace in next line /path/to/destination/directory by your destination directory path for html files.
*/
$coverageTreemapField = new atoum\report\fields\runner\coverage\treemap('Authentication profiles for AuthStack', '/var/www/coverage/authstack/authprofile/treemap');

/*
Please replace in next line http://url/of/treemap by the root url of your treemap web site.
*/
$coverageTreemapField
    ->setTreemapUrl('http://coverage.buckhill.com.hr/authstack/authprofile/treemap')
    ->setHtmlReportBaseUrl($coverageHtmlField->getRootUrl())
;

$script
    ->addDefaultReport()
        ->addField($coverageHtmlField)
        ->addField($coverageTreemapField)
;
